# Simple-PyDB 3.0.1
A simple local file-based database module.

![Python](https://img.shields.io/badge/python-%2314354C.svg?style=for-the-badge&logo=python&logoColor=white)  ![Version](https://img.shields.io/static/v1?label=Version&message=3.0.1&style=for-the-badge&labelColor=222831&color=393E46) ![Downloads](https://img.shields.io/github/downloads/sanalzio/PyDB/2.0/total?label=DOWNLOADS&style=for-the-badge&labelColor=393E46&color=00ADB5) ![Python Version](https://img.shields.io/static/v1?label=Version&message=3.x&style=for-the-badge&labelColor=4B8BBE&color=FFE873&logo=python&logoColor=ffffff) ![LICENSE](https://img.shields.io/static/v1?label=LICENSE&message=GPLv3&style=for-the-badge)

# Installation
## For Gnu/Linux or MacOS
```bash
python3 -m pip install s-pydb
```
## For windows
```
pip install s-pydb
```

# Documentation
### [-> Click to go PyDB documentation <-](https://sanalzio.github.io/PyDB/)
